@@ -14,6 +14,9 @@ import utils.sql_utils as sqlUtils
 import utils.table_utils as tableUtils
 import utils.generation as genUtils
 
+# pylint: disable=missing-function-docstring
+# pylint: disable=missing-class-docstring
+# pylint: disable=invalid-name
 
 def new_database():
     return ColemenDatabase()
@@ -140,7 +143,7 @@ class ColemenDatabase:
             if 'database' not in creds:
                 error_array.append('database is not provided in db_credentials')
             if len(error_array) == 0:
-                print("Successfully validated db_credentials")
+                # print("Successfully validated db_credentials")
                 return True
             return False
 
@@ -183,7 +186,7 @@ class ColemenDatabase:
                 )
 
                 if self.con.is_connected():
-                    print("Successfully connected to mysql database")
+                    # print("Successfully connected to mysql database")
                     connect_success = True
 
             except Error as error:
@@ -222,7 +225,7 @@ class ColemenDatabase:
             `method_name`: run
         '''
         statements = sql
-        # if the sql is a string, split it into a list separate statements
+        # if the sql is a string, split it into a list of statements
         if isinstance(sql, (str)):
             statements = sqlUtils.to_statement_list(sql)
 
@@ -265,18 +268,20 @@ class ColemenDatabase:
 
         try:
             if args is False:
+                # print(f"executing sql: ",sql)
                 self.cur.execute(sql)
             else:
                 args = genUtils.sanitize_quotes(args)
-                self.cur.execute(sql, args)
+                result = self.cur.execute(sql, args)
+                # print(f"result: ",result)
 
             self.con.commit()
             success = True
 
         except mysql.connector.errors.DatabaseError:
             # print(f"ERROR: {err}", PRESET="FATAL_ERROR_INVERT")
-            print(f"{traceback.format_exc()}", PRESET="FATAL_ERROR_INVERT")
-            print(f"SQL: {sql}", PRESET="FATAL_ERROR_INVERT")
+            print(f"{traceback.format_exc()}")
+            print(f"SQL: {sql}")
 
         except sqlite3.Warning as error:
             print(f"Warning: {error}")
@@ -287,9 +292,9 @@ class ColemenDatabase:
             print(traceback.format_exc())
 
         except AttributeError:
-            print(f"{traceback.format_exc()}", PRESET="FATAL_ERROR_INVERT")
+            print(f"{traceback.format_exc()}")
             print("")
-            print(f"{print(sys.exc_info()[2])}", PRESET="FATAL_ERROR_INVERT")
+            print(f"{print(sys.exc_info()[2])}")
             print("")
             print("")
             print(f"SQL: \033[38;2;(235);(64);(52)m{sql}")
@@ -314,7 +319,7 @@ class ColemenDatabase:
                         "name":"DISABLE_KEY_RESTRAINTS",
                         "is_keywarg":True,
                         "type":"boolean",
-                        "description":"If True, temporarily disable FOREIGN_KEY_CHECKS while executing the queries",
+                        "description":"If True, temporarily disable foreign_key_checks while executing the queries",
                         "is_optional":True
                     }
                 ]
@@ -323,12 +328,13 @@ class ColemenDatabase:
         if 'DISABLE_KEY_RESTRAINTS' in kwargs:
             if kwargs['DISABLE_KEY_RESTRAINTS'] is False:
                 disableForeignKeyRestraints = False
+        if disableForeignKeyRestraints is True:
+            self.run("SET foreign_key_checks = 0;")
         for q in query_list:
-            if disableForeignKeyRestraints is True:
-                self.run("SET FOREIGN_KEY_CHECKS=0;")
             self.run(q)
-            if disableForeignKeyRestraints is True:
-                self.run("SET FOREIGN_KEY_CHECKS=1;")
+
+        if disableForeignKeyRestraints is True:
+            self.run("SET foreign_key_checks = 1;")
 
     def runMulti(self, sql, args):
         sql = sql.replace(";", ";STATEMENT_END")
@@ -389,18 +395,17 @@ class ColemenDatabase:
                         "name":"DISABLE_KEY_RESTRAINTS",
                         "is_keywarg":True,
                         "type":"boolean",
-                        "description":"If True, temporarily disable FOREIGN_KEY_CHECKS while executing the queries",
+                        "description":"If True, temporarily disable foreign_key_checks while executing the queries",
                         "is_optional":True
-                    }        
+                    }
                 ]
             }"""
         with open(filePath, 'r', encoding='utf-8') as file:
             sql = file.read()
-            # print(f"sql: {sql}")
             sql = sql.replace(";", ";STATEMENT_END")
             statements = sql.split('STATEMENT_END')
 
-        # self.run("SET FOREIGN_KEY_CHECKS=0;")
+        # self.run("SET foreign_key_checks=0;")
         # "SOURCE /backups/mydump.sql;" -- restore your backup within THIS session
         # statements = getSQLStatementsFromFile(filePath)
         # print(f"statements: {statements}")
@@ -408,10 +413,8 @@ class ColemenDatabase:
         if 'DISABLE_KEY_RESTRAINTS' in kwargs:
             if kwargs['DISABLE_KEY_RESTRAINTS'] is False:
                 disableForeignKeyRestraints = False
-        self.runFromList(statements, DISABLE_KEY_RESTRAINTS=disableForeignKeyRestraints)
-        # self.run("SET FOREIGN_KEY_CHECKS=1;")
-
-        return
+        return self.runFromList(statements, DISABLE_KEY_RESTRAINTS=disableForeignKeyRestraints)
+        # self.run("SET foreign_key_checks=1;")
 
     def to_dict(self, result):
         # print(f"to_dict: resultType: {type(result)}")
@@ -468,10 +471,10 @@ class ColemenDatabase:
 
     def generateColumnInsertString(self, table_name):
         collar = self.table.get_column_array(table_name)
-        print(f"{collar}")
+        # print(f"{collar}")
 
         colStr = self.gen.array_to_list_string(collar, ITEM_WRAP="`", LIST_WRAP="(")
-        print(f"{colStr}")
+        # print(f"{colStr}")
 
     def generateColumnValueStrings(self, data):
         # print("---generateColumnValueStrings---")
